@@ -57,15 +57,17 @@ def send_notifications(email, sender, email_configuration):
 
     RECIPIENT = email
     # The subject line for the email.
-    SUBJECT = email_configuration.get('SUBJECT')
-    LOG_PATH = email_configuration.get('LOG_PATH')
+    SUBJECT = email_configuration.get('Subject')
+    LOG_PATH = email_configuration.get('Log_path')
 
     # The full path to the file that will be attached to the email.
     ATTACHMENT = LOG_PATH
-
+    cover = email_configuration.get('Banner')
+    logo = email_configuration.get('Logo')
+    paragraph = email_configuration.get('Email_Content')
     # # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
-    email_html= open(file_name)
+    email_html = open(file_name)
     BODY_HTML = email_html.read()
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
