@@ -45,12 +45,18 @@ class SenderEmailConfiguration(TimeStampedModel):
 class EmailConfiguration(TimeStampedModel):
     """Model for Email Configuration """
 
-    SUBJECT = models.CharField(max_length=200, null=True)
+    Subject = models.CharField(max_length=200, null=True)
+
+    Logo = models.ImageField(help_text="Please upload your logo here")
+
+    Banner = models.ImageField(help_text="Please upload your banner here")
+
+    Log_path = models.CharField(max_length=200, null=True)
+
+    Email_Content = models.TextField(max_length=200, null=True)
 
     HTML_File = models.FileField(help_text='Upload the html file')
 
-    LOG_PATH = models.CharField(max_length=200, null=True)
-
     def get_absolute_url(self):
         """ URL for displaying individual model records."""
         return reverse('Configuration-detail', args=[str(self.id)])
